<?php
namespace PriceGuide\Report;



/**
 * Stock Control Report.
 * @author andre.fourie
 */
class PriceGuideGrid extends \Utility\Service\Report
{



	/**
	 * @var string
	 */
	protected $_title  = 'Price Guide Data Export';
	/**
	 * @var string
	 */
	protected $_subject = 'Vehicles on price guide.';
	/**
	 * @var string
	 */
	protected $_description = 'Export of vehicles available on price guide.';
	/**
	 * @var array
	 */
	protected $_notes = array(
			'Confidential information, generated using Bid 4 Cars, for more information visit bid4cars.com.na'
			);
	/**
	 * @var array
	 */
	protected $_headers = array(
			'Seller',
			'Group',
			'Division',
			'Region',
			'Reference Number',
			'Registration Number',
			'VIN Number',
			'Make',
			'Model',
			'Type',
			'Year',
			'Main Exterior Colour',
			'KM',
			'Trade Price',
			'Retail Price',
			'Number of price guide offers',
			'Highest price guide offer',
			'My offer',
			'Status',
			'Created',
			'Updated'
			);
	/**
	 * @var array
	 */
	protected $_fields = array(
			'company_name',
			'companyGroup_name',
			'groupDivision_name',
			'region_name',
			'stock_referenceNumber',
			'stock_registrationNumber',
			'stock_vinNumber',
			'make_name',
			'model_name',
			'type_name',
			'vehicleYear_name',
			'exteriorColour_name',
			'stock_km',
			'stock_tradePrice',
			'stock_retailPrice',
            'stock_listPrice',
			'stock_numberOfOffers',
			'stock_highestOffer',
			'priceGuide_id',
			'priceGuide_jobState',
			'priceGuide_created',
			'priceGuide_updated'
			);
	/**
	 * @var array
	 */
	protected $_totals = array(
			'stock_tradePrice',
			'stock_retailPrice',
            'stock_listPrice',
			'stock_retailAmountRequired',
			'stock_highestOffer',
			'priceGuide_id'
			);
	/**
	 * @var array
	 */
	protected $_currencyFields = array(
			'stock_tradePrice',
			'stock_retailPrice',
            'stock_listPrice',
			'stock_retailAmountRequired',
			'stock_highestOffer',
			'priceGuide_id'
			);



	/**
	 * Build the dataset, or not.
	 */
	public function build()
	{
		#-> Data passed by DataBin Grid functionality.
		$dateTimeFormat = \Utility\Definitions\Locale::getDateTimeFormat();
		$auth = \Utility\Registry::getAuthData();
		foreach ($this->_data as $rowId => $rowData)
		{
			$myOffer = $this->em->getRepository('\PriceGuide\Entity\Offer')
				->findOneBy(array(
					'priceGuideStock' => $this->_data[$rowId]['priceGuide_id'],
					'company' => $auth['company']['id']
				));
			$this->_data[$rowId]['priceGuide_id'] = is_object($myOffer)
				? $myOffer->amount
				: 0.0;
			$this->em->clear('\PriceGuide\Entity\Offer');
			$this->_data[$rowId]['priceGuide_created'] = $rowData['priceGuide_created']->format($dateTimeFormat);
			$this->_data[$rowId]['priceGuide_updated'] = !is_null($rowData['priceGuide_updated'])
				? $rowData['priceGuide_updated']->format($dateTimeFormat)
				: '';
			if ('Updateable Offers' == $this->_data[$rowId]['priceGuide_jobState'] || 'Open4Offers' == $this->_data[$rowId]['priceGuide_jobState'])
			{
				$this->_data[$rowId]['stock_highestOffer'] = 0.0;
			}
		}
	}

}
